@@ -14,7 +14,7 @@ configure_sentry()
 def main(event, context):
     # Get parameters
     path_params = event.get('pathParameters', {}) or {}
-    query_params = event.get('queryStringParameters', {}) or {}
+    query_params = event.get('multiValueQueryStringParameters', {}) or {}
 
     try:
         api = DynamoAPI(
